@@ -20,6 +20,7 @@ from __future__ import absolute_import
 import locale
 import logging.handlers
 import os
+import sqlite3
 import sys
 import time
 
@@ -31,6 +32,7 @@ from solfege import application
 from solfege import buildinfo
 from solfege import cfg
 from solfege import filesystem
+from solfege import gu
 from solfege import lessonfile
 from solfege import optionparser
 from solfege import osutils
@@ -139,7 +141,14 @@ def start_gui(datadir):
     def f(s):
         if solfege.splash_win:
             solfege.splash_win.show_progress(s)
-    solfege.db = statistics.DB(f, profile=options.profile)
+    if solfege.splash_win:
+        solfege.splash_win.show_progress(_("Opening statistics database"))
+    try:
+        solfege.db = statistics.DB(f, profile=options.profile)
+    except sqlite3.OperationalError, e:
+        solfege.splash_win.hide()
+        gu.dialog_ok(_("Failed to open the statistics database:\n«%s»") % str(e).decode(sys.getfilesystemencoding(), 'replace'), secondary_text=_("Click OK to exit the program. Then try to quit all other instances of the program, or reboot the computer. You can only run one instance of GNU Solfege at once."))
+        sys.exit()
 
     if solfege.splash_win:
         solfege.splash_win.show_progress(_("Creating application window"))
