@@ -70,6 +70,9 @@ class TrainingSetDialog(gtk.Window, gu.EditorDialogBase, lessonfilegui.Exercises
         for s in ('midi', 'wav', 'mp3', 'ogg'):
             hbox.pack_start(self.g_output[s], False)
         ####
+        hbox.pack_start(gtk.VSeparator(), False)
+        self.g_named_tracks = gtk.CheckButton(_("Name files by questions"))
+        hbox.pack_start(self.g_named_tracks, False)
         self.g_liststore = gtk.ListStore(
             gobject.TYPE_STRING, # filename
             gobject.TYPE_STRING, # visible exercise name
@@ -220,6 +223,7 @@ class TrainingSetDialog(gtk.Window, gu.EditorDialogBase, lessonfilegui.Exercises
         self.m_filename = filename
         if p.globals['fileformat_version'] == 1:
             lessonfile.require_mgr()
+        self.g_named_tracks.set_active(p.globals.get('named_tracks', False))
         for lesson in p.blocklists.setdefault('lesson', []):
             # In this loop we will set the filename column of the liststore
             # to None if there is any problem, and set a title mentioning
@@ -246,7 +250,7 @@ class TrainingSetDialog(gtk.Window, gu.EditorDialogBase, lessonfilegui.Exercises
                     lesson['delay']))
             else:
                 self.g_liststore.append((filename,
-                    _("Unknown lessson_id: <b>%s</b>") % lesson['lesson_id'],
+                    _("Unknown lesson_id: <b>%s</b>") % lesson['lesson_id'],
                     lesson['count'],
                     lesson['repeat'],
                     lesson['delay']))
@@ -261,6 +265,7 @@ class TrainingSetDialog(gtk.Window, gu.EditorDialogBase, lessonfilegui.Exercises
         print >> f, "# Training set definition file for GNU Solfege %s" % buildinfo.VERSION_STRING
         print >> f, "\nfileformat_version = %i" % self.fileformat_version
         print >> f, "output_format = \"%s\"" % [k for k in self.g_output if self.g_output[k].get_active()][0]
+        print >> f, "named_tracks = %s" % (u"yes" if self.g_named_tracks.get_active() else u"no")
         iter = self.g_liststore.get_iter_first()
         while iter:
             print >> f, "lesson {"
@@ -323,7 +328,7 @@ class TrainingSetDialog(gtk.Window, gu.EditorDialogBase, lessonfilegui.Exercises
         while gtk.events_pending():
             gtk.main_iteration(0)
         try:
-            for prog in solfege.app.export_training_set(v, export_to, output_format):
+            for prog in solfege.app.export_training_set(v, export_to, output_format, self.g_named_tracks.get_active()):
                 progress_bar.set_fraction(prog)
                 while gtk.events_pending():
                     gtk.main_iteration(0)
